pub struct SigningCommitments<C: Ciphersuite> { /* private fields */ }Expand description
Published by each participant in the first round of the signing protocol.
This step can be batched if desired by the implementation. Each SigningCommitment can be used for exactly one signature.
Implementations
Sourceimpl<C: Ciphersuite> SigningCommitments<C>
Auto-generated by derive_getters::Getters.
impl<C: Ciphersuite> SigningCommitments<C>
Auto-generated by derive_getters::Getters.
Sourcepub fn hiding(&self) -> &NonceCommitment<C>
pub fn hiding(&self) -> &NonceCommitment<C>
Commitment to the hiding Nonce.
Sourcepub fn binding(&self) -> &NonceCommitment<C>
pub fn binding(&self) -> &NonceCommitment<C>
Commitment to the binding Nonce.
Sourceimpl<C> SigningCommitments<C>where
C: Ciphersuite,
impl<C> SigningCommitments<C>where
C: Ciphersuite,
Sourcepub fn new(hiding: NonceCommitment<C>, binding: NonceCommitment<C>) -> Self
pub fn new(hiding: NonceCommitment<C>, binding: NonceCommitment<C>) -> Self
Create new SigningCommitments
Sourceimpl<C> SigningCommitments<C>where
C: Ciphersuite,
impl<C> SigningCommitments<C>where
C: Ciphersuite,