SigningNonces

Struct SigningNonces 

pub struct SigningNonces<C: Ciphersuite> { /* private fields */ }
Comprised of hiding and binding nonces.

Note that SigningNonces must be used only once for a signing operation; re-using nonces will result in leakage of a signer’s long-lived signing key.

Implementations

Source

impl<C: Ciphersuite> SigningNonces<C>

Auto-generated by derive_getters::Getters.

pub fn hiding(&self) -> &Nonce<C>

The hiding Nonce.

pub fn binding(&self) -> &Nonce<C>

The binding Nonce.

pub fn commitments(&self) -> &SigningCommitments<C>

The commitments to the nonces. This is precomputed to improve sign() performance, since it needs to check if the commitments to the participant’s nonces are included in the commitments sent by the Coordinator, and this prevents having to recompute them.

Source

impl<C> SigningNonces<C>
where C: Ciphersuite,

pub fn new<R>(secret: &SigningShare<C>, rng: &mut R) -> Self
where R: CryptoRng + RngCore,

Generates a new signing nonce.

Each participant generates signing nonces before performing a signing operation.

pub fn from_nonces(hiding: Nonce<C>, binding: Nonce<C>) -> Self

Generates a new SigningNonces from a pair of Nonce.

Security

SigningNonces MUST NOT be repeated in different FROST signings. Thus, if you’re using this method (because e.g. you’re writing it to disk between rounds), be careful so that does not happen.

Source

impl<C> SigningNonces<C>
where C: Ciphersuite,

pub fn serialize(&self) -> Result<Vec<u8>, Error<C>>

Available on crate feature serialization only.

Serialize the struct into a Vec.

pub fn deserialize(bytes: &[u8]) -> Result<Self, Error<C>>

Available on crate feature serialization only.

Deserialize the struct from a slice of bytes.