pub struct BindingFactorList<C: Ciphersuite>(/* private fields */);Expand description
A list of binding factors and their associated identifiers.
Implementations
Sourceimpl<C> BindingFactorList<C>where
C: Ciphersuite,
impl<C> BindingFactorList<C>where
C: Ciphersuite,
Sourcepub fn get(&self, key: &Identifier<C>) -> Option<&BindingFactor<C>>
pub fn get(&self, key: &Identifier<C>) -> Option<&BindingFactor<C>>
Get the BindingFactor for the given identifier, or None if not found.