SigningPackage

Struct SigningPackage 

pub struct SigningPackage<C: Ciphersuite> { /* private fields */ }
Generated by the coordinator of the signing operation and distributed to each signing party

Implementations

Source

impl<C: Ciphersuite> SigningPackage<C>

Auto-generated by derive_getters::Getters.

pub fn signing_commitments( &self, ) -> &BTreeMap<Identifier<C>, SigningCommitments<C>>

The set of commitments participants published in the first round of the protocol.

pub fn message(&self) -> &Vec<u8>

Message which each participant will sign.

Each signer should perform protocol-specific verification on the message.

Source

impl<C> SigningPackage<C>
where C: Ciphersuite,

pub fn new( signing_commitments: BTreeMap<Identifier<C>, SigningCommitments<C>>, message: &[u8], ) -> SigningPackage<C>

Create a new SigningPackage

The signing_commitments are sorted by participant identifier.

pub fn signing_commitment( &self, identifier: &Identifier<C>, ) -> Option<SigningCommitments<C>>

Get a signing commitment by its participant identifier, or None if not found.

pub fn binding_factor_preimages( &self, verifying_key: &VerifyingKey<C>, additional_prefix: &[u8], ) -> Result<Vec<(Identifier<C>, Vec<u8>)>, Error<C>>

Available on crate feature internals only.

Compute the preimages to H1 to compute the per-signer binding factors

Source

impl<C> SigningPackage<C>
where C: Ciphersuite,

pub fn serialize(&self) -> Result<Vec<u8>, Error<C>>

Available on crate feature serialization only.

Serialize the struct into a Vec.

pub fn deserialize(bytes: &[u8]) -> Result<Self, Error<C>>

Available on crate feature serialization only.

Deserialize the struct from a slice of bytes.