pub fn aggregate_custom<C>(
signing_package: &SigningPackage<C>,
signature_shares: &BTreeMap<Identifier<C>, SignatureShare<C>>,
pubkeys: &PublicKeyPackage<C>,
cheater_detection: CheaterDetection,
) -> Result<Signature<C>, Error<C>>where
C: Ciphersuite,Expand description
Like aggregate(), but allow specifying a specific cheater detection
strategy. If you are disabling cheater detection, then the identifiers
in signature_shares do not need to correspond to the senders (i.e.
you don’t need to authenticate the origin of the shares).