pub struct SigningNonces<C: Ciphersuite> { /* private fields */ }Expand description
Comprised of hiding and binding nonces.
Note that SigningNonces must be used only once for a signing
operation; re-using nonces will result in leakage of a signer’s long-lived
signing key.
Implementations
Sourceimpl<C: Ciphersuite> SigningNonces<C>
Auto-generated by derive_getters::Getters.
impl<C: Ciphersuite> SigningNonces<C>
Auto-generated by derive_getters::Getters.
Sourcepub fn commitments(&self) -> &SigningCommitments<C>
pub fn commitments(&self) -> &SigningCommitments<C>
The commitments to the nonces. This is precomputed to improve sign() performance, since it needs to check if the commitments to the participant’s nonces are included in the commitments sent by the Coordinator, and this prevents having to recompute them.
Sourceimpl<C> SigningNonces<C>where
C: Ciphersuite,
impl<C> SigningNonces<C>where
C: Ciphersuite,
Sourcepub fn new<R>(secret: &SigningShare<C>, rng: &mut R) -> Self
pub fn new<R>(secret: &SigningShare<C>, rng: &mut R) -> Self
Generates a new signing nonce.
Each participant generates signing nonces before performing a signing operation.
Sourcepub fn from_nonces(hiding: Nonce<C>, binding: Nonce<C>) -> Self
pub fn from_nonces(hiding: Nonce<C>, binding: Nonce<C>) -> Self
Generates a new SigningNonces from a pair of Nonce.
Security
SigningNonces MUST NOT be repeated in different FROST signings. Thus, if you’re using this method (because e.g. you’re writing it to disk between rounds), be careful so that does not happen.
Sourceimpl<C> SigningNonces<C>where
C: Ciphersuite,
impl<C> SigningNonces<C>where
C: Ciphersuite,